Module Name:    src
Committed By:   joerg
Date:           Mon Mar  1 00:14:08 UTC 2010

Modified Files:
        src/dist/pf/sbin/pfctl: pfctl_altq.c

Log Message:
Use HUGE_VAL instead of INFINITY as positive infinity (or maximum value)
is good enough and the side effects of ISO C99 7.12 (4) are not desired.


To generate a diff of this commit:
cvs rdiff -u -r1.8 -r1.9 src/dist/pf/sbin/pfctl/pfctl_altq.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/dist/pf/sbin/pfctl/pfctl_altq.c
diff -u src/dist/pf/sbin/pfctl/pfctl_altq.c:1.8 src/dist/pf/sbin/pfctl/pfctl_altq.c:1.9
--- src/dist/pf/sbin/pfctl/pfctl_altq.c:1.8	Wed Jun 18 09:06:26 2008
+++ src/dist/pf/sbin/pfctl/pfctl_altq.c	Mon Mar  1 00:14:08 2010
@@ -1,4 +1,4 @@
-/*	$NetBSD: pfctl_altq.c,v 1.8 2008/06/18 09:06:26 yamt Exp $	*/
+/*	$NetBSD: pfctl_altq.c,v 1.9 2010/03/01 00:14:08 joerg Exp $	*/
 /*	$OpenBSD: pfctl_altq.c,v 1.92 2007/05/27 05:15:17 claudio Exp $	*/
 
 /*
@@ -881,9 +881,6 @@
 /*
  * admission control using generalized service curve
  */
-#ifndef __NetBSD__
-#define	INFINITY	HUGE_VAL  /* positive infinity defined in <math.h> */
-#endif /* !__NetBSD__ */
 
 /* add a new service curve to a generalized service curve */
 static void
@@ -893,7 +890,7 @@
 		return;
 	if (sc->d != 0)
 		gsc_add_seg(gsc, 0.0, 0.0, (double)sc->d, (double)sc->m1);
-	gsc_add_seg(gsc, (double)sc->d, 0.0, INFINITY, (double)sc->m2);
+	gsc_add_seg(gsc, (double)sc->d, 0.0, HUGE_VAL, (double)sc->m2);
 }
 
 /*
@@ -917,10 +914,10 @@
 		return (1);
 	}
 	/*
 	 * gsc has a dummy entry at the end with x = INFINITY.
 	 * loop through up to this dummy entry.
 	 */
-	end = gsc_getentry(gsc, INFINITY);
+	end = gsc_getentry(gsc, HUGE_VAL);
 	if (end == NULL)
 		return (1);
 	last = NULL;
@@ -977,10 +974,10 @@
 		return (NULL);
 
 	new->x = x;
-	if (x == INFINITY || s == NULL)
+	if (x == HUGE_VAL || s == NULL)
 		new->d = 0;
-	else if (s->x == INFINITY)
-		new->d = INFINITY;
+	else if (s->x == HUGE_VAL)
+		new->d = HUGE_VAL;
 	else
 		new->d = s->x - x;
 	if (prev == NULL) {
@@ -993,12 +990,12 @@
 		 * the start point intersects with the segment pointed by
 		 * prev.  divide prev into 2 segments
 		 */
-		if (x == INFINITY) {
-			prev->d = INFINITY;
+		if (x == HUGE_VAL) {
+			prev->d = HUGE_VAL;
 			if (prev->m == 0)
 				new->y = prev->y;
 			else
-				new->y = INFINITY;
+				new->y = HUGE_VAL;
 		} else {
 			prev->d = x - prev->x;
 			new->y = prev->d * prev->m + prev->y;
@@ -1016,8 +1013,8 @@
 	struct segment	*start, *end, *s;
 	double		 x2;
 
-	if (d == INFINITY)
-		x2 = INFINITY;
+	if (d == HUGE_VAL)
+		x2 = HUGE_VAL;
 	else
 		x2 = x + d;
 	start = gsc_getentry(gsc, x);
@@ -1030,7 +1027,7 @@
 		s->y += y + (s->x - x) * m;
 	}
 
-	end = gsc_getentry(gsc, INFINITY);
+	end = gsc_getentry(gsc, HUGE_VAL);
 	for (; s != end; s = LIST_NEXT(s, _next)) {
 		s->y += m * d;
 	}
@@ -917,10 +914,10 @@
 	}
 	/*
-	 * gsc has a dummy entry at the end with x = INFINITY.
+	 * gsc has a dummy entry at the end with x = HUGE_VAL.
 	 * loop through up to this dummy entry.
 	 */

Reply via email to